@@ -1,13 +1,23 @@
-unit module PerlMongers::Hannover;
+package PerlMongers::Hannover;
 
-sub info is export {
-    my $path = "$*CWD";
-    my $package = $path ~ "/lib/PerlMongers/Hannover.pm";
-    my $cmd = "perl6 --doc $package";
-    qqx{$cmd};
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+
+use strict;
+use warnings;
+require Exporter;
+
+@ISA = qw(Exporter);
+@EXPORT_OK = qw(info);
+
+use v5.10.1;
+
+sub info {
+    system('perldoc', __PACKAGE__);
 }
 
-=begin pod
+1;
+
+__END__
 
 =head1 NAME
 
@@ -15,13 +25,13 @@ PerlMongers::Hannover - Hannover Perl Mongers
 
 =head1 VERSION
 
-Version 0.8.6
+Version 0.5.5
 
 =head1 SYNOPSIS
 
-    use PerlMongers::Hannover;
+    use PerlMongers::Hannover qw(info);
 
-    info.say;
+    info();
 
 =head2 Website
 
@@ -29,7 +39,7 @@ http://hannover.pm
 
 =head2 IRC Channel
 
-L<irc://irc.perl.org/#hannover.pm>
+irc.perl.org #hannover.pm
 
 =head2 Mailing List
 
@@ -41,7 +51,7 @@ L<mailto:hannover-pm@pm.org>
 
 =head2 Meetups
 
-Every second and fourth Thursday at 6pm; date and location details announced
+Every odd calendar week Tuesday at 6pm; date and location details announced
 via Twitter, email and via the web site:
 
 http://hannover.pm/treffen
@@ -76,7 +86,7 @@ L<https://github.com/paultcochrane/PerlMongers-Hannover>
 
 =head1 AUTHOR
 
-Paul Cochrane <ptc@hannover.pm>
+Paul Cochrane <paul@hannover.pm>
 
 =head1 NOTES
 
@@ -85,11 +95,9 @@ modeled after C<PerlMongers::Bangalore>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015-2016 by Hannover Perl Mongers.
+This software is copyright (c) 2014 by Hannover Perl Mongers.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-=end pod
-
-# vim: expandtab shiftwidth=4 ft=perl6
+=cut
